# -*- coding: utf-8 -*-

mapping = (
    u"abvgdezijklmnoprstufhcABVGDEZIJKLMNOPRSTUFHC",
    u"абвгдезијклмнопрстуфхцАБВГДЕЗИЈКЛМНОПРСТУФХЦ",
)

reversed_specific_mapping = (
    u"",
    u""
)

pre_processor_mapping = {
    u"gj": u"ѓ",
    u"zh": u"ж",
    u"dz": u"ѕ",
    u"lj": u"љ",
    u"nj": u"њ",
    u"кј": u"ќ",
    u"ch": u"ч",
    u"dzh": u"џ",
    u"sh": u"ш",
    u"Gj": u"Ѓ",
    u"Zh": u"Ж",
    u"Dz": u"Ѕ",
    u"Lj": u"Љ",
    u"Nj": u"Њ",
    u"Kj": u"Ќ",
    u"Ch": u"Ч",
    u"Dzh": u"Џ",
    u"Sh": u"Ш",
}
