# -*- coding: utf-8 -*-

mapping = (
    "abvgdjziklmnouprstuufheABVGDJZIKLMNOUPRSTUUFHE",
    "абвгджзиклмноөпрстуүфхэАБВГДЖЗИКЛМНОӨПРСТУҮФХЭ",
)
reversed_specific_mapping = (
    "ъьЪЬйЙ",
    "iiIIiI"
)
pre_processor_mapping = {
    "ii": "ы",
    "II": "Ы",
    "ye": "е",
    "YE": "Е",
    "yo": "ё",
    "YO": "Ё",
    "ts": "ц",
    "TS": "Ц",
    "ch": "ч",
    "CH": "Ч",
    "sh": "ш",
    "SH": "Ш",
    "sh": "щ",
    "SH": "Щ",
    "yu": "ю",
    "YU": "Ю",
    "ya": "я",
    "YA": "Я",
}
