# -*- coding: utf-8 -*-

mapping = (
    "abgdezilkhmjnpsvturqoABGDEZILKHMJNPSVTURQO",
    "აბგდეზილქჰმჯნფსვთურყოႠႡႢႣႤႦႨႪႵჀႫႿႼႴႱႥႧႳႰႷႭ",
)
pre_processor_mapping = {
    "k'": "კ",
    "p'": "პ",
    "zh'": "ჟ",
    "t'": "ტ",
    "gh": "ღ",
    "sh": "შ",
    "ch": "ჩ",
    "ts": "ც",
    "dz": "ძ",
    "ts'": "წ",
    "ch'": "ჭ",
    "kh": "ხ",
    "K'": "Ⴉ",
    "P'": "Ⴎ",
    "Zh'": "Ⴏ",
    "T'": "Ⴒ",
    "Gh": "Ⴖ",
    "Sh": "Ⴘ",
    "Ch": "Ⴙ",
    "Ts": "Ⴚ",
    "Dz": "Ⴛ",
    "Ts'": "Ⴜ",
    "Ch'": "Ⴝ",
    "Kh": "Ⴞ",
}
