# -*- coding: utf-8 -*-

mapping = (
    u"abvhgdezyijklmnoprstuf'ABVHGDEZYIJKLMNOPRSTUF'",
    u"абвгґдезиійклмнопрстуфьАБВГҐДЕЗИІЙКЛМНОПРСТУФЬ",
)
reversed_specific_mapping = (
    u"ьЬ",
    u"''"
)
pre_processor_mapping = {
    u"ye": u"є",
    u"zh": u"ж",
    u"yi": u"ї",
    u"kh": u"х",
    u"ts": u"ц",
    u"ch": u"ч",
    u"sh": u"ш",
    u"shch": u"щ",
    u"ju": u"ю",
    u"ja": u"я",
    u"Ye": u"Є",
    u"Zh": u"Ж",
    u"Yi": u"Ї",
    u"Kh": u"Х",
    u"Ts": u"Ц",
    u"Ch": u"Ч",
    u"Sh": u"Ш",
    u"Shch": u"Щ",
    u"Ju": u"Ю",
    u"Ja": u"Я"
}