from transliterate.utils import (
    translit, get_available_language_codes, detect_language, slugify
)
from transliterate.utils import get_available_language_packs

__title__ = 'transliterate'
__version__ = '1.8'
__build__ = 0x000019
__author__ = 'Artur Barseghyan'
__copyright__ = '2013-2016 Artur Barseghyan'
__license__ = 'GPL 2.0/LGPL 2.1'
__all__ = (
    'translit', 'get_available_language_codes', 'detect_language', 'slugify',
    'get_available_language_packs',
)
