# -*- coding: utf-8 -*-

mapping = (
        "abgdezilxkhmjnpsvtrcq&ofABGDEZILXKHMJNPSVTRCQOF",
        "աբգդեզիլխկհմյնպսվտրցքևօֆԱԲԳԴԵԶԻԼԽԿՀՄՅՆՊՍՎՏՐՑՔՕՖ",
    )
reversed_specific_mapping = (
    "ռՌ",
    "rR"
)
reversed_specific_pre_processor_mapping = {
    "ու": "u",
    "Ու": "U"
}
pre_processor_mapping = {
    # lowercase
    "e'": "է",
    "y": "ը",
    "th": "թ",
    "jh": "ժ",
    "ts": "ծ",
    "dz": "ձ",
    "gh": "ղ",
    "tch": "ճ",
    "sh": "շ",
    "vo": "ո",
    "ch": "չ",
    "dj": "ջ",
    "ph": "փ",
    "u": "ու",

    # uppercase
    "E'": "Է",
    "Y": "Ը",
    "Th": "Թ",
    "Jh": "Ժ",
    "Ts": "Ծ",
    "Dz": "Ձ",
    "Gh": "Ղ",
    "Tch": "Ճ",
    "Sh": "Շ",
    "Vo": "Ո",
    "Ch": "Չ",
    "Dj": "Ջ",
    "Ph": "Փ",
    "U": "Ու"
}
