# -*- coding: utf-8 -*-

mapping = (
    u"abvgdezijklmnoprstufh'y'ABVGDEZIJKLMNOPRSTUFH'Y'",
    u"абвгдезийклмнопрстуфхъыьАБВГДЕЗИЙКЛМНОПРСТУФХЪЫЬ",
)
reversed_specific_mapping = (
    u"ёэЁЭъьЪЬ",
    u"eeEE''''"
)
pre_processor_mapping = {
    u"zh": u"ж",
    u"ts": u"ц",
    u"ch": u"ч",
    u"sh": u"ш",
    u"sch": u"щ",
    u"ju": u"ю",
    u"ja": u"я",
    u"Zh": u"Ж",
    u"Ts": u"Ц",
    u"Ch": u"Ч",
    u"Sh": u"Ш",
    u"Sch": u"Щ",
    u"Ju": u"Ю",
    u"Ja": u"Я"
}
