# -*- coding: utf-8 -*-

mapping = (
    "abvgdezijklmnoprstufh'y'ABVGDEZIJKLMNOPRSTUFH'Y'",
    "абвгдезийклмнопрстуфхъыьАБВГДЕЗИЙКЛМНОПРСТУФХЪЫЬ",
)
reversed_specific_mapping = (
    "ёэЁЭъьЪЬ",
    "eeEE''''"
)
pre_processor_mapping = {
    "zh": "ж",
    "ts": "ц",
    "ch": "ч",
    "sh": "ш",
    "sch": "щ",
    "ju": "ю",
    "ja": "я",
    "Zh": "Ж",
    "Ts": "Ц",
    "Ch": "Ч",
    "Sh": "Ш",
    "Sch": "Щ",
    "Ju": "Ю",
    "Ja": "Я"
}
