# -*- coding: utf-8 -*-

mapping = (
    "avgdeziklmnxoprstyfAVGDEZIKLMNXOPRSTYF",
    "αβγδεζικλμνξοπρστυφΑΒΓΔΕΖΙΚΛΜΝΞΟΠΡΣΤΥΦ",
)
reversed_specific_mapping = (
    "ςάέήίύόώϊϋΐΰωΩηΗϵϱ",
    "saeiiyooiyiyooiier"
)
pre_processor_mapping = {
    "th": "ϑ",
    "Th": "θ",
    "ch": "χ",
    "Ch": "Χ",
    "ps": "ψ",
    "Ps": "Ψ",
    "Gk": "Γκ",
    "gk": "γκ",
    "gx": "γξ",
    "nx": "γξ",
    "nch":"γξ",
    "gch":"γξ",
    "B" : "Μπ",
    "Ev": "Ευ",
    "Ef": "Ευ",
    "Ey": "Ευ",
    "ev": "ευ",
    "ef": "ευ",
    "ey": "ευ",

    "Iv": "Ηυ",
    "If": "Ηυ",
    "Iy": "Ηυ",
    "iv": "ηυ",
    "if": "ηυ",
    "iy": "ηυ",

    "b" : "μπ",
    "A": "Αυ",
    "a": "αυ",
    "E": "Ευ",
    "e": "ευ",
    "O": "Ου",
    "o": "ου",
    "Oy": "Ου",
    "oy": "ου",
    "": "Υ",
    "": "υ",
    "Yi": "Υι",
    "yi": "υι",
    "Oi": "Οι",
    "oi": "οι",
    "ng": "γγ",
}
