# -*- coding: utf-8 -*-

mapping = (
    u"avgdeziklmnxoprstyfAVGDEZIKLMNXOPRSTYF",
    u"αβγδεζικλμνξοπρστυφΑΒΓΔΕΖΙΚΛΜΝΞΟΠΡΣΤΥΦ",
)
reversed_specific_mapping = (
    u"ςάέήίύόώϊϋΐΰωΩηΗϵϱ",
    u"saeiiyooiyiyooiier"
)
pre_processor_mapping = {
    u"th": u"ϑ",
    u"Th": u"θ",
    u"ch": u"χ",
    u"Ch": u"Χ",
    u"ps": u"ψ",
    u"Ps": u"Ψ",
    u"Gk": u"Γκ",
    u"gk": u"γκ",
    u"gx": u"γξ",
    u"nx": u"γξ",
    u"nch":u"γξ",
    u"gch":u"γξ",
    u"B" : u"Μπ",
    u"Ev": u"Ευ",
    u"Ef": u"Ευ",
    u"Ey": u"Ευ",
    u"ev": u"ευ",
    u"ef": u"ευ",
    u"ey": u"ευ",

    u"Iv": u"Ηυ",
    u"If": u"Ηυ",
    u"Iy": u"Ηυ",
    u"iv": u"ηυ",
    u"if": u"ηυ",
    u"iy": u"ηυ",

    u"b" : u"μπ",
    u"Au": u"Αυ",
    u"au": u"αυ",
    u"Eu": u"Ευ",
    u"eu": u"ευ",
    u"Ou": u"Ου",
    u"ou": u"ου",
    u"Oy": u"Ου",
    u"oy": u"ου",
    u"U": u"Υ",
    u"u": u"υ",
    u"Yi": u"Υι",
    u"yi": u"υι",
    u"Oi": u"Οι",
    u"oi": u"οι",
    u"ng": u"γγ",
}
