# -*- coding: utf-8 -*-

mapping = (
    u"abvgdeziyklmnoprstufhABVGDEZIYKLMNOPRSTUFH",
    u"абвгдезийклмнопрстуфхАБВГДЕЗИЙКЛМНОПРСТУФХ",
)

reversed_specific_mapping = (
    u"ьъЪ",
    u"yaA"
)

pre_processor_mapping = {
    u"zh": u"ж",
    u"ts": u"ц",
    u"ch": u"ч",
    u"sh": u"ш",
    u"sht": u"щ",
    u"yu": u"ю",
    u"ya": u"я",
    u"Zh": u"Ж",
    u"Ts": u"Ц",
    u"Ch": u"Ч",
    u"Sh": u"Ш",
    u"Sht": u"Щ",
    u"Yu": u"Ю",
    u"Ya": u"Я"
}
