# -*- coding: utf-8 -*-

mapping = (
    "abvgdezijklmnoprstufhcABVGDEZIJKLMNOPRSTUFHC",
    "абвгдезијклмнопрстуфхцАБВГДЕЗИЈКЛМНОПРСТУФХЦ",
)

reversed_specific_mapping = (
    "",
    ""
)

pre_processor_mapping = {
    "gj": "ѓ",
    "zh": "ж",
    "dzh": "ѕ",
    "lj": "љ",
    "nj": "њ",
    "кј": "ќ",
    "ch": "ч",
    "dj": "џ",
    "sh": "ш",
    "Gj": "Ѓ",
    "Zh": "Ж",
    "Dz": "Ѕ",
    "Lj": "Љ",
    "Nj": "Њ",
    "Kj": "Ќ",
    "Ch": "Ч",
    "Dzh": "Џ",
    "Sh": "Ш",
}
