# -*- coding: utf-8 -*-

mapping = (
    u"abgdezilkhmjnpsvturqoABGDEZILKHMJNPSVTURQO",
    u"აბგდეზილქჰმჯნფსვთურყოႠႡႢႣႤႦႨႪႵჀႫႿႼႴႱႥႧႳႰႷႭ",
)
pre_processor_mapping = {
    u"k'": u"კ",
    u"p'": u"პ",
    u"zh'": u"ჟ",
    u"t'": u"ტ",
    u"gh": u"ღ",
    u"sh": u"შ",
    u"ch": u"ჩ",
    u"ts": u"ც",
    u"dz": u"ძ",
    u"ts'": u"წ",
    u"ch'": u"ჭ",
    u"kh": u"ხ",
    u"K'": u"Ⴉ",
    u"P'": u"Ⴎ",
    u"Zh'": u"Ⴏ",
    u"T'": u"Ⴒ",
    u"Gh": u"Ⴖ",
    u"Sh": u"Ⴘ",
    u"Ch": u"Ⴙ",
    u"Ts": u"Ⴚ",
    u"Dz": u"Ⴛ",
    u"Ts'": u"Ⴜ",
    u"Ch'": u"Ⴝ",
    u"Kh": u"Ⴞ",
}
